==> android-platform-libcore_7.0.0+r33.orig.tar.gz: ojluni/src/main/java/javax/security/auth/PrivateCredentialPermission.java <==
/*
 * Copyright (c) 1999, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package javax.security.auth;

import java.util.*;
import java.security.Permission;
import java.security.Principal;

/**
 * Legacy security code; do not use.
 */
public final class PrivateCredentialPermission extends Permission {

    PrivateCredentialPermission(String credentialClass,
                                Set<Principal> principals) { super(""); }

    public PrivateCredentialPermission(String name, String actions) { super(""); }

    public String getCredentialClass() { return null; }

    public String[][] getPrincipals() { return null; }

    public boolean implies(Permission p) { return true; }

    public String getActions() { return null; }
}

==> android-platform-libcore_10.0.0+r36.orig.tar.gz: ojluni/src/main/java/javax/security/auth/PrivateCredentialPermission.java <==
/*
 * Copyright (c) 1999, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package javax.security.auth;

import java.util.*;
import java.security.Permission;
import java.security.Principal;

// Android-changed: Stubbed the implementation.  Android doesn't support SecurityManager.
// See comments in java.lang.SecurityManager for details.
/**
 * Legacy security code; do not use.
 */
public final class PrivateCredentialPermission extends Permission {

    PrivateCredentialPermission(String credentialClass,
                                Set<Principal> principals) { super(""); }

    public PrivateCredentialPermission(String name, String actions) { super(""); }

    public String getCredentialClass() { return null; }

    public String[][] getPrincipals() { return null; }

    public boolean implies(Permission p) { return true; }

    public String getActions() { return null; }
}
